@@ -5,5 +5,5 @@ from django.conf.urls.defaults import patterns, url
 from django_states.views import make_state_transition
 
 urlpatterns = patterns('',
-    url(r'^make-state-transition/$', make_state_transition, name='states2_make_transition'),
+    url(r'^make-state-transition/$', make_state_transition, name='django_states_make_transition'),
 )
